@@ -32,6 +32,7 @@ import org.apache.flink.statefun.sdk.Address;
 import org.apache.flink.statefun.sdk.Context;
 import org.apache.flink.statefun.sdk.FunctionType;
 import org.apache.flink.statefun.sdk.io.EgressIdentifier;
+import org.apache.flink.statefun.sdk.metrics.Metrics;
 import org.junit.Test;
 
 public class LocalStatefulFunctionGroupTest {
@@ -141,6 +142,11 @@ public class LocalStatefulFunctionGroupTest {
     @Override
     public <M, T> void registerAsyncOperation(M metadata, CompletableFuture<T> future) {}
 
+    @Override
+    public Metrics metrics() {
+      throw new UnsupportedOperationException();
+    }
+
     @Override
     public void apply(LiveFunction function, Message inMessage) {
       in = inMessage;
