@@ -46,6 +46,8 @@ import org.apache.flink.statefun.sdk.AsyncOperationResult;
 import org.apache.flink.statefun.sdk.AsyncOperationResult.Status;
 import org.apache.flink.statefun.sdk.FunctionType;
 import org.apache.flink.statefun.sdk.io.EgressIdentifier;
+import org.apache.flink.statefun.sdk.metrics.Counter;
+import org.apache.flink.statefun.sdk.metrics.Metrics;
 import org.apache.flink.statefun.sdk.reqreply.generated.FromFunction;
 import org.apache.flink.statefun.sdk.reqreply.generated.FromFunction.DelayedInvocation;
 import org.apache.flink.statefun.sdk.reqreply.generated.FromFunction.EgressMessage;
@@ -201,6 +203,50 @@ public class RequestReplyFunctionTest {
     assertEquals(Duration.ofMillis(1), context.delayed.get(0).delay());
   }
 
+  @Test
+  public void delayedMessagesWithCancellationToken() {
+    functionUnderTest.invoke(context, TypedValue.getDefaultInstance());
+
+    FromFunction response =
+        FromFunction.newBuilder()
+            .setInvocationResult(
+                InvocationResponse.newBuilder()
+                    .addDelayedInvocations(
+                        DelayedInvocation.newBuilder()
+                            .setArgument(TypedValue.getDefaultInstance())
+                            .setDelayInMs(1)
+                            .setCancellationToken("foo")
+                            .build()))
+            .build();
+
+    functionUnderTest.invoke(context, successfulAsyncOperation(response));
+
+    assertFalse(context.delayed.isEmpty());
+    assertEquals(Duration.ofMillis(1), context.delayed.get(0).delay());
+    assertEquals("foo", context.delayed.get(0).cancellationToken);
+  }
+
+  @Test
+  public void delayedMessagesCancellation() {
+    functionUnderTest.invoke(context, TypedValue.getDefaultInstance());
+
+    FromFunction response =
+        FromFunction.newBuilder()
+            .setInvocationResult(
+                InvocationResponse.newBuilder()
+                    .addDelayedInvocations(
+                        DelayedInvocation.newBuilder()
+                            .setIsCancellationRequest(true)
+                            .setCancellationToken("foo")
+                            .build()))
+            .build();
+
+    functionUnderTest.invoke(context, successfulAsyncOperation(response));
+
+    assertFalse(context.delayCancellations.isEmpty());
+    assertEquals("foo", context.delayCancellations.get(0));
+  }
+
   @Test
   public void egressIsSent() {
     functionUnderTest.invoke(context, TypedValue.getDefaultInstance());
@@ -380,14 +426,14 @@ public class RequestReplyFunctionTest {
 
   private static final class DelayedMessage {
     final Duration delay;
-    final @Nullable String messageId;
+    final @Nullable String cancellationToken;
     final Address target;
     final Object message;
 
     public DelayedMessage(
-        Duration delay, @Nullable String messageId, Address target, Object message) {
+        Duration delay, @Nullable String cancellationToken, Address target, Object message) {
       this.delay = delay;
-      this.messageId = messageId;
+      this.cancellationToken = cancellationToken;
       this.target = target;
       this.message = message;
     }
@@ -398,7 +444,7 @@ public class RequestReplyFunctionTest {
 
     @Nullable
     public String messageId() {
-      return messageId;
+      return cancellationToken;
     }
 
     public Address target() {
@@ -420,6 +466,7 @@ public class RequestReplyFunctionTest {
     // capture emitted messages
     List<Map.Entry<EgressIdentifier<?>, ?>> egresses = new ArrayList<>();
     List<DelayedMessage> delayed = new ArrayList<>();
+    List<String> delayCancellations = new ArrayList<>();
 
     @Override
     public void awaitAsyncOperationComplete() {
@@ -460,10 +507,24 @@ public class RequestReplyFunctionTest {
     }
 
     @Override
-    public void cancelDelayedMessage(String cancellationToken) {}
+    public void cancelDelayedMessage(String cancellationToken) {
+      delayCancellations.add(cancellationToken);
+    }
 
     @Override
     public <M, T> void registerAsyncOperation(M metadata, CompletableFuture<T> future) {}
+
+    @Override
+    public Metrics metrics() {
+      return name ->
+          new Counter() {
+            @Override
+            public void inc(long amount) {}
+
+            @Override
+            public void dec(long amount) {}
+          };
+    }
   }
 
   private static final class BacklogTrackingMetrics implements FunctionTypeMetrics {
@@ -484,6 +545,11 @@ public class RequestReplyFunctionTest {
       numBacklog -= count;
     }
 
+    @Override
+    public Metrics functionTypeScopedMetrics() {
+      throw new UnsupportedOperationException();
+    }
+
     @Override
     public void remoteInvocationFailures() {}
 
